@@ -32,9 +32,9 @@ def start(args):
 
                     print("Getting project requirements...")
 
-                    #f = open(f"{path}/pandio_requirements.txt", "w")
-                    #f.write("pandioml>=1.0.6")
-                    #f.close()
+                    f = open(f"{path}/pandio_requirements.txt", "w")
+                    f.write("pandioml>=1.0.6")
+                    f.close()
 
                     hash = hashlib.md5(bytes(args.project_folder, 'utf-8'))
                     tmp_path = tmp_path + hash.hexdigest() + '/'
